@@ -2,7 +2,7 @@ from .abstract import Abstract
 from .archive import Archive
 from .base import Base
 from .callbacks import Callbacks
-from .cf_protect import CloudFlareProtect
+from .cf_protect import cf_scrape
 from .chapter_helper import ChapterHelper
 from .static import Static
 from .web_driver import WebDriver
