@@ -9,10 +9,10 @@ class MangaKakalotCom(Provider, Std):
         return re.group(1).replace('.', '-', 2)
 
     def get_main_content(self):
-        return self._get_content('{}/manga/{}')
+        return self.http_get(self.get_url())
 
     def get_manga_name(self) -> str:
-        return self._get_name('/(?:manga|chapter)/([^/]+)/?')
+        return self._get_name(r'/read-(\w+)')
 
     def get_chapters(self):
         return self._elements('.chapter-list span a')
